1 files changed, 8 insertions, 5 deletions
diff --git a/synapse/api/constants.py b/synapse/api/constants.py
index 8c7ad2a407..a986fdb47a 100644
--- a/synapse/api/constants.py
+++ b/synapse/api/constants.py
@@ -120,6 +120,7 @@ class EventTypes:
SpaceParent = "m.space.parent"
MSC2716_INSERTION = "org.matrix.msc2716.insertion"
+ MSC2716_CHUNK = "org.matrix.msc2716.chunk"
MSC2716_MARKER = "org.matrix.msc2716.marker"
@@ -198,15 +199,13 @@ class EventContentFields:
# Used on normal messages to indicate they were historically imported after the fact
MSC2716_HISTORICAL = "org.matrix.msc2716.historical"
- # For "insertion" events
+ # For "insertion" events to indicate what the next chunk ID should be in
+ # order to connect to it
MSC2716_NEXT_CHUNK_ID = "org.matrix.msc2716.next_chunk_id"
# Used on normal message events to indicate where the chunk connects to
MSC2716_CHUNK_ID = "org.matrix.msc2716.chunk_id"
# For "marker" events
MSC2716_MARKER_INSERTION = "org.matrix.msc2716.marker.insertion"
- MSC2716_MARKER_INSERTION_PREV_EVENTS = (
- "org.matrix.msc2716.marker.insertion_prev_events"
- )
class RoomTypes:
@@ -230,3 +229,7 @@ class HistoryVisibility:
JOINED = "joined"
SHARED = "shared"
WORLD_READABLE = "world_readable"
+
+
+class ReadReceiptEventFields:
+ MSC2285_HIDDEN = "org.matrix.msc2285.hidden"
|
@@ -198,15 +199,13 @@ class EventContentFields:
MSC2716_NEXT_CHUNK_ID = "org.matrix.msc2716.next_chunk_id"
- # Used on normal message events to indicate where the chunk connects to
+ # Used on "chunk" events to indicate which insertion event it connects to
MSC2716_CHUNK_ID = "org.matrix.msc2716.chunk_id"
# For "marker" events